import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// defines the Colors for Pie Chart different sections
const sectionColors = [
  		'pink', 'yellow', 'blue', 'green', 'red', 'orange', 'purple', 'brown', 'black', 'violet'
		  ];

// link or URL of my dataset which is different countries accidentrate
const csvUrl = 'https://gist.githubusercontent.com/Sheshidharreddy/ce828863717da30a4450c9948f60f26b/raw/d28e8f68392a009e55648acaa8c12d34224cec1a/units.csv';

// Function to get or retrive the data from the URL
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

//text of Format axes
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// These are used to render Pie Chart 
const render = (data, total) => {
  const pieData = pie().value(d=>d.units)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  // used for generating Arcs of the different sections
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  
	const segments = arc()
  	.innerRadius(100)
  	.outerRadius(210)
  	.padAngle(0)
  	.padRadius(0);
  //Here it get data from svg file
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.units));
  

  
  // Here create the legned for the chart 
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.units));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.CarName);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat(d.data.units));
  	
}

// Main function
const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.units = +d.units;
    total += d.units
  });
	render(data,total);
};
run();